{{ appname }} assets
================================================================================

Files in this directory are not version controlled via git.
If Git LFS is installed, they are tracked via Git LFS.

If not, they are ignored by `../.gitignore`, and you need to deploy these files
manually, or via shared drives such as Google Drive, Dropbox, Seafile, etc.


Folder structure
--------------------------------------------------------------------------------

We recommend creating sub-folders as follows:

- `assets/img/`     has images
- `assets/data/`    has data files (e.g. TopoJSON maps, XLSX, CSV, SQLite files)
- `assets/fonts/`   has custom fonts (if required)
